function PMatrix = calcPrior2D (IP, prior)
% function Pr = calcPrior2D (IP, prior) 
% calculates prior in image domain
%
% Parameters:
% IP:       3 x 2 matrix; parameters specifying image:
%           row 1: vector containing no. of image pixels in x and y
%           row 2: sampling distance of image in x an y
%           row 3: shift of image window in x an y
%
% prior:    n x 5 matrix specifying the prior;
%           the total prior is defined as the superposition of n sub-strutures
%           each sub-structures is defined by 5 entries:
%           column 1:    number key specifying type of prior (<100 matlab; >100 C code); 
%                        implemented are:
%                        rectangle -> function 'rect2D'; key: 1/101; 4 additional parameters
%			             disk      -> function 'disk2D'; key: 2/102; 3 additional parameters
%           column 2:    weight
%           column 3-6:  additional parameters to specify prior; for prior specifued with less than
%                        four parameters, the matrix must be filled with dummy values.
%
% Pr:       matrix containing prior in the image domain
%
% (c) Markus Testorf, Vers. 6.0, November 22, 2002
%

% This program is free software; you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by
% the Free Software Foundation; either version 2 of the License, or
% (at your option) any later version.
%
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
%
% You should have received a copy of the GNU General Public License
% along with this program; if not, write to the Free Software
% Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.


i=sqrt(-1.0);

Np = length(prior(:,1));
%Ne = IP(1);
nx=IP(1,1);
ny=IP(1,2);
%PMatrix = zeros (nx);

%for xx = 1:nx
%    for yy = 1:ny
%        PMatrix(xx,yy)=1;
%    end
%end


PMatrix = zeros (IP(1,:));

%mm=1;

% loop over all sub priors
for mm = 1: Np,
    if prior(mm,1) == 101,
        PMatrix = PMatrix + prior(mm,2)*rect2D(IP, prior(mm,3:6));
    elseif prior(mm,1) == 102,
        PMatrix = PMatrix + prior(mm,2)*disk2D(IP, prior(mm,3:6));
    %elseif prior(mm,1) == 103,
    %    PMatrix = PMatrix  ftcos2D(IP, prior(mm,3:6));
    end
end

   


