function v = ftDisk2D (In, pr)
% function v = ftDisk2D (nu, mu, pr)
% 
% calculates the Fourier transformation of a shifted disk
% disk(\sqrt{(x-pr(2))^2+(y-pr(3)}/pr(1));
% The Fourier transform is assumed to be 
%  F(nu,mu) = \int f(x,y) \exp[-i2\pi(x nu + y mu)]
%
% for use with PDFT2D algorithm;
%
% at present nu and mu must be scalar;
%
% Parameters:
% nu, mu    spatial frequency in x and y for which the function is evaluated;
%
% pr:       1 x 3 vector defining the disk;
%           1st element: radius of the disk; 
%           2nd element: x coordinate of disk center;
%           3rd element: y coordinate of disk center;

% v:        = FT[disk] evaluated at nu and mu;
%
% (c) Markus Testorf, Vers. 5.0, Sept. 17, 2000
% 

% This program is free software; you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by
% the Free Software Foundation; either version 2 of the License, or
% (at your option) any later version.
%
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
%
% You should have received a copy of the GNU General Public License
% along with this program; if not, write to the Free Software
% Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.

nu = In(:,1);
mu = In(:,2);

Ne=length(nu(:,1));
v = zeros(Ne, Ne);
i=sqrt(-1.0);

statuspt = Ne/10;percentdone = 0;
count = 0;

%fprintf('\nCalculating Prior ');

for rr = 1:Ne
    
        count = count+1;
                if(count >= statuspt)
                    fprintf('.');
                    count = 0;
                    percentdone = percentdone+1;
                    if(percentdone == 2)
                        fprintf('25%%')
                    end
                    if(percentdone == 5)
                        fprintf('50%%');
                    end
                    if(percentdone == 7)
                        fprintf('.75%%')
                    end
                end
    
    for cc = 1:Ne
    
        r = sqrt((nu(rr)-nu(cc))^2 + (mu(rr)-mu(cc))^2);
    
        if r > 0
        
            v(rr,cc) = pr(1)*besselj(1,2*pi*pr(1)*r)*exp(-i*2*pi*(pr(2)*(nu(rr)-nu(cc))+pr(3)*(mu(rr)-mu(cc))))/r;
        
        else
        
            v(rr,cc) = pi * pr(1)^2;
        end
    end
end

fprintf('.. Done\n');
    
    
    

