function PMatrix = genPmatrix1D (sfreq, prior, regularize)
% function PMatrix = genPmatrix1D (sfreq, prior, regularize)
% function to generate P-matrix for PDFT algorithm
% 
% Parameters:
% sfreq:      N x 1 vector containing coordinates of data points in Fourier space
% prior:      n x 4 matrix specifying the prior;
%             the total prior is defined as the superposition of n sub-strutures
%             each sub-structures is defined by 5 entries:
%             column 1:    number key specifying type of prior (<100 matlab; >100 C code); 
%                          implemented are:
%                          rectangle -> function 'rect2D'; key: 201/301; 2 additional parameters
%             column 2:    weight
%             column 3-4:  additional parameters to specify prior; for prior specifued with less than
%                          four parameters, the matrix must be filled with dummy values.
%
% regularize: regularization parameter
%
% PMatrix:    P-matrix ("FT of prior")
%
% see also 'pdft1D', 'rect1D', 'pMeval'
%
%
% (c) Markus Testorf, Vers. 6.0, November 22, 2002
%

% This program is free software; you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by
% the Free Software Foundation; either version 2 of the License, or
% (at your option) any later version.
%
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
%
% You should have received a copy of the GNU General Public License
% along with this program; if not, write to the Free Software
% Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.

i=sqrt(-1.0);

Np = length(prior(:,1));
Ne = length(sfreq(:,1));
PMatrix = zeros (Ne);

% loop over all sub priors
for mm = 1: Np,
    if prior(mm,1) == 301,
        PMatrix = PMatrix + prior(mm,2).*cFTRect1D (sfreq, prior(mm,3:4));
    else
        ftprior = ['ft' pMeval(prior(mm,1))];
        for jj = 1:Ne
            for kk = 1:Ne
                PMatrix(kk,jj) = PMatrix(kk,jj) + prior(mm,2).*feval(ftprior, sfreq(kk)-sfreq(jj), prior(mm,3:4));
            end              
        end
    end
end

for jj=1:Ne
   PMatrix(jj,jj) = PMatrix(jj,jj) * regularize;
end


