function Image = idft2D (In, IP)
% function Image = idft2D (In, IP, mode, dispecho) 
% Image estimation of 2D images via inverse DFT series
% 
% Parameters:
% In:         Matrix containing input data
%             column 1: nu  spatial frequency in x
%             column 2: mu  spatial frequency in y
%             column 3: data (complex)
%
% IP:         3 x 2 matrix containing image parameters of image format:
%             row 1: vector containing no. of image pixels in x and y
%             row 2: sampling distance of image in x an y
%             row 3: shift of image window in x an y
%
% mode:       specifies subroutines called
%             'matlab' (default): calls subroutine coded exclusively in Matlab
%             'ccode'           : calls subroutines coded in c (only available for Windows)
%
% dispecho:   specfifies echo output mode
%             'show' (default)  : outputs progress information
%             'quiet'           : runs without output
%
%
% Image:      Image Matrix
%
% (c) Markus Testorf, Vers. 5.0, Sept. 17, 2001
%

% This program is free software; you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by
% the Free Software Foundation; either version 2 of the License, or
% (at your option) any later version.
%
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
%
% You should have received a copy of the GNU General Public License
% along with this program; if not, write to the Free Software
% Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.


i=sqrt(-1.0);    % .... because Matlab has its downsides

%if nargin < 3,
%   mode     = 'matlab';
%   dipsecho = 'show'
%elseif nargin < 4,
%    dispecho = 'show';
%end


%if strcmp(dispecho, 'show'), disp('- idft2D, (c) M. Testorf, Vers. 5.0, Sept. 17, 2001 -'); end

% setup output matrix
nx = IP(1,1);  % ... extracting no. of image points in x
ny = IP(1,2);  % ... extracting no. of image points in y
dx = IP(2,1);  % ... extracting sampling distance in x
dy = IP(2,2);  % ... extracting sampling distance in y
sx = IP(3,1);  % ... extracting shift of image window in x
sy = IP(3,2);  % ... extracting shift of image window in y 

Image = zeros (nx,ny);


%if strcmp(mode,'matlab'),
    % calculate image estimate via DFT
    for ix=1:nx
        for iy=1:ny
            Image(ix,iy) = sum(In(:,3) .* exp(i.*2.0.*pi.* ...
                (In(:,1).*(dx.*(ix-nx/2-1)+sx)+ In(:,2).*(dy.*(iy-ny/2-1)+sy))));
        end
    end
% else
%     Image = cidft2D(In, IP);
%end
