function keyno = mPeval (funstr, mode)
% function keyno = mPeval (funstr)
% utility function for pdft algorithm; converts P-matrix funtion string into key number
% 
% Parameters:
% funstr:     function string corresponding to key
%
% mode:       computation mode:
%             'matlab'    : pure Matlab code
%             'ccode'     : C low level code whenever possible
%
% keyno:      number pecifying the prior;
%             implemented are:
%             1   -> 2D rectangle; function 'rect2D'
%			  2   -> 2D disk;      function 'disk2D'
%             201 -> 1D rectangle; function 'rect1D'
%
% see also pdft1D', 'rect1D', 'genPmatrix1D, 'pdft2D', 'rect2D', 'disk2D', 'genPmatrix2D', 'pMeval'
%
%
% (c) Markus Testorf, Vers. 6.0, Nov. 22, 2002
%

% This program is free software; you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by
% the Free Software Foundation; either version 2 of the License, or
% (at your option) any later version.
%
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
%
% You should have received a copy of the GNU General Public License
% along with this program; if not, write to the Free Software
% Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.

if nargin < 2,
   mode     = 'matlab';
end


if     strcmp(funstr, 'rect2D'),
    keyno = 1;
elseif strcmp(funstr, 'disk2D'),
    keyno = 2;
elseif strcmp(funstr, 'cos2D'),
    keyno = 3;
elseif strcmp(funstr, 'rect1D'),
    keyno = 201,
else
    error('mPeval - unknown function!!');
end

if strcmp(mode, 'ccode'),
    keyno = keyno + 100;
end


