function C = rect2D (IP, prior)
% function C = rect2D (x, y, pr)
%
% returns function values of rect((x-pr(3))/pr(1))*rect((y-pr(4))/pr(2));
% for use with PDFT2D algorithm;
% at present x and y must be scalar;
%
% (c) Markus Testorf, Vers. 5.0, Sept. 17, 2000
%

% This program is free software; you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by
% the Free Software Foundation; either version 2 of the License, or
% (at your option) any later version.
%
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
%
% You should have received a copy of the GNU General Public License
% along with this program; if not, write to the Free Software
% Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.

nx = IP(1,1);  % ... extracting no. of image points in x
ny = IP(1,2);  % ... extracting no. of image points in y
dx = IP(2,1);  % ... extracting sampling distance in x
dy = IP(2,2);  % ... extracting sampling distance in y
sx = IP(3,1);  % ... extracting shift of image window in x
sy = IP(3,2);  % ... extracting shift of image window in y 

C = zeros(nx,ny);

x0 = nx/2+prior(3)/dx;
y0 = ny/2+prior(4)/dy;

Xmax = prior(:,1)/2;
Ymax = prior(:,2)/2;

for rr = 1:nx
    for cc = 1:ny
        
        xx = abs(rr-x0)*dx;
        yy = abs(cc-y0)*dy;
        
        if xx<Xmax && yy<Ymax
            C(rr,cc)=1;
        else
            C(rr,cc)=0;
        end
    end
end
            



   
